Class: Coradoc::AsciiDoc::Model::Inline::HardLineBreak
Overview
Hard line break inline element for AsciiDoc documents.
Hard line breaks force a line break at a specific point. Rendered as a plus sign at the end of a line: +.
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
#block_level?, #serialize_content, #simplify_block_content, #to_adoc, #to_h, visit, #visit
Instance Method Details
#inline? ⇒ Boolean
17 18 19 |
# File 'lib/coradoc/asciidoc/model/inline/hard_line_break.rb', line 17 def inline? :hardbreak end |