Class: Coradoc::AsciiDoc::Model::List::Nestable

Inherits:
Base
  • Object
show all
Defined in:
lib/coradoc/asciidoc/model/list/nestable.rb

Overview

Marker class for lists that can be nested inside a List::Item via its nested attribute. Inherits universal list attributes (id, attrs) from List::Base.

List::Definition does not extend Nestable because it has its own nesting model via List::DefinitionItem#nested.

Direct Known Subclasses

Core

Instance Attribute Summary

Attributes inherited from Base

#attrs

Attributes inherited from Base

#id

Method Summary

Methods inherited from Base

#block_level?

Methods included from Anchorable

#default_anchor, #gen_anchor, included, #initialize

Methods inherited from Base

#block_level?, #inline?, #serialize_content, #simplify_block_content, #to_adoc, #to_h, visit, #visit