Class: Coradoc::AsciiDoc::Model::Attached
- Defined in:
- lib/coradoc/asciidoc/model/attached.rb
Overview
Base class for attached elements in AsciiDoc documents.
Attached elements are those that can be attached to other elements such as list items or blocks. They include admonitions, paragraphs, and other block types.
This class provides the foundation for elements that can be “attached” to parent elements in the document structure.
Direct Known Subclasses
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
#inline?, #serialize_content, #simplify_block_content, #to_adoc, #to_h, visit, #visit
Instance Method Details
#block_level? ⇒ Boolean
20 21 22 |
# File 'lib/coradoc/asciidoc/model/attached.rb', line 20 def block_level? true end |