Class: Coradoc::AsciiDoc::Model::Inline::Link
Overview
Link inline element for AsciiDoc documents.
Links can be external URLs or internal references.
Instance Attribute Summary collapse
-
#name ⇒ String?
readonly
Optional link text/alias.
-
#path ⇒ String
readonly
The URL or path the link points to.
-
#right_constrain ⇒ Boolean
readonly
Whether to constrain the link on the right (default: false).
-
#title ⇒ String?
readonly
Optional tooltip text for the link.
Attributes inherited from Base
Method Summary
Methods inherited from Base
Methods inherited from Base
#block_level?, #inline?, #serialize_content, #simplify_block_content, #to_adoc, #to_h, visit, #visit
Instance Attribute Details
#name ⇒ String? (readonly)
Returns Optional link text/alias.
37 38 39 40 41 42 |
# File 'lib/coradoc/asciidoc/model/inline/link.rb', line 37 class Link < Base attribute :path, :string attribute :title, :string attribute :name, :string attribute :right_constrain, :boolean, default: -> { false } end |
#path ⇒ String (readonly)
Returns The URL or path the link points to.
37 38 39 40 41 42 |
# File 'lib/coradoc/asciidoc/model/inline/link.rb', line 37 class Link < Base attribute :path, :string attribute :title, :string attribute :name, :string attribute :right_constrain, :boolean, default: -> { false } end |
#right_constrain ⇒ Boolean (readonly)
Returns Whether to constrain the link on the right (default: false).
37 38 39 40 41 42 |
# File 'lib/coradoc/asciidoc/model/inline/link.rb', line 37 class Link < Base attribute :path, :string attribute :title, :string attribute :name, :string attribute :right_constrain, :boolean, default: -> { false } end |
#title ⇒ String? (readonly)
Returns Optional tooltip text for the link.
37 38 39 40 41 42 |
# File 'lib/coradoc/asciidoc/model/inline/link.rb', line 37 class Link < Base attribute :path, :string attribute :title, :string attribute :name, :string attribute :right_constrain, :boolean, default: -> { false } end |