Class: Coradoc::AsciiDoc::Model::List::Nestable
Overview
Marker class for lists that can be nested inside a List::Item via its nested attribute. Inherits universal list attributes (id, attrs) from List::Base.
List::Definition does not extend Nestable because it has its own nesting model via List::DefinitionItem#nested.
Direct Known Subclasses
Instance Attribute Summary
Attributes inherited from Base
Attributes inherited from Base
Method Summary
Methods inherited from Base
Methods included from Anchorable
#default_anchor, #gen_anchor, included, #initialize
Methods inherited from Base
#block_level?, #inline?, #serialize_content, #simplify_block_content, #to_adoc, #to_h, visit, #visit